import { useState, useEffect } from "react";
import { Table, Button, Space, Tag } from "antd";
import axios from "axios";

export const Dashboard = () => {
  const [dataSource, setDatasource] = useState<[]>([]);
  const [expandedRowData, setExpandedRowData] = useState({});
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    const fetchData = async () => {
      const { data } = await axios.post("/api/top");
      if (data)
        setDatasource(
          data.map((i: any) => ({
            ...i,
            key: i.user_id,
            nickName: i.user_nickName,
            user_level: i.user_level,
            user_fans_club_level: i.user_fans_club_level,
          }))
        );
    };
    fetchData();
  }, []);

  const columns = [
    {
      title: "#",
      key: "index",
      render: (text, record, index) => index + 1, // 添加序号列
    },
    {
      title: "昵称",
      key: "nickName",
      render: (record: any) => {
        return (
          <Space>
            <span>{record.user_nickName}</span>
            {record.user_isAdmin == 1 && <Tag color="magenta">管</Tag>}
            {record.user_is_super_admin == 1 && <Tag color="red">超管</Tag>}
          </Space>
        );
      },
    },
    {
      title: "抖音级别",
      dataIndex: "user_level",
      key: "user_level",
    },
    {
      title: "粉丝团级别",
      dataIndex: "user_fans_club_level",
      key: "user_fans_club_level",
    },
  ];

  const expandedRowRender = (record) => {
    const { key: user_id } = record;
    const data = expandedRowData[user_id];
    if (loading) return <p>正在加载数据...</p>;
    if (data)
      return (
        <>
          {data.map((i, index) => (
            <div key={index}>{i}</div>
          ))}
        </>
      );
    return null;
  };

  const onExpand = async (expanded, record) => {
    const { key: user_id } = record;
    if (user_id in expandedRowData || !expanded) return;
    setLoading(true);
    const { data } = await axios.get(`/api/msg_content/${user_id}`);
    setExpandedRowData((p) => ({ ...p, [user_id]: data }));
    setLoading(false);
  };

  return (
    <Table
      dataSource={dataSource}
      columns={columns}
      expandable={{
        onExpand,
        expandedRowRender,
      }}
    ></Table>
  );
};
